import request from '@/utils/request';
import axios from 'axios';
import Cookie from '@/common/cookie';
import {getCurrentLanguage, languageCode2BELocalCode} from '@/common/i18n';
import {userApi, ethApi} from './app';

const Host = userApi + '/';
const Host1 = ethApi + '/';

//登录
export function signIn(data) {
  return request({
    method: 'post',
    url: Host + 'login/password2',
    params: data,
    timeout: -1,
  });
}

//注册
export function signUp(data) {
  return request({
    method: 'post',
    url: Host + 'login/register2',
    params: data,
    timeout: -1,
  });
}

//获取注册验证码
export function getVerCode(data) {
  return request({
    method: 'post',
    url: Host + 'login/sendRegisterCode',
    params: data,
  });
}

//修改昵称
export function rename(data) {
  return request({
    method: 'post',
    url: Host + 'user/updateNickName',
    params: data,
  });
}

//用户信息
export function getUserData() {
  return request({
    method: 'post',
    url: Host + 'user/me',
  });
}

//用户登录日志
export function getLoginLog(data) {
  return request({
    method: 'post',
    url: Host + 'userLoginLog/listUserLoginLog',
    params: data,
  });
}

//提交实名认证
export function submitProve(data) {
  return request({
    method: 'post',
    url: Host + 'user/saveIdcardVali',
    params: data,
  });
}

//获取更改手机的验证码
export function getchangeCode(data) {
  return request({
    method: 'post',
    url: Host + 'user/sendChangePhoneCode',
    params: data,
  });
}

//修改手机号
export function changePhone(data) {
  return request({
    method: 'post',
    url: Host + 'user/updateTel',
    params: data,
  });
}

//退出登录
export function logOut() {
  return request({
    method: 'post',
    url: Host + 'login/loginout2',
  });
}

//获取忘记密码验证码
export function getForgotCode(tel, internationalCode) {
  let data = {
    tel: tel,
    internationalCode: internationalCode,
  };
  return request({
    method: 'post',
    url: Host + 'login/setForgetCode',
    params: data,
  });
}

//忘记密码
export function forgotPassword(tel, code, password) {
  let data = {
    tel: tel,
    code: code,
    password: password,
  };
  return request({
    method: 'get',
    url: Host + 'login/resetPassword',
    params: data,
  });
}

//支付密碼
export function getPayPassword() {
  return request({
    method: 'get',
    url: Host1 + 'wallet/existsPass',
  });
}

//获取邮箱验证码
export function getEmailCode(data) {
  return request({
    method: 'get',
    url: Host + 'user/sendEmailCode',
    params: data,
    timeout: -1,
  });
}

//绑定邮箱
export function bindEmail(data) {
  return request({
    method: 'get',
    url: Host + 'user/bindEmail',
    params: data,
  });
}

//获取google验证器的key
export function getGoogleKey() {
  return request({
    method: 'get',
    url: Host + 'user/getGoogleKey',
  });
}

//绑定google验证器
export function bingGoogle(data) {
  return request({
    method: 'post',
    url: Host + 'user/bindGoogle',
    params: data,
  });
}

//修改登录密码
export function changeLoginPassword(data) {
  return request({
    method: 'get',
    url: Host + 'user/updatePassword',
    params: data,
  });
}

//获取设置资金密码的验证码
export function getMoneyCode(internationalCode) {
  let data = {
    internationalCode: internationalCode,
  };
  return request({
    method: 'get',
    url: Host + 'user/sendMoneyPasswordSmsg',
    params: data,
  });
}

//设置资金密码
export function setMoneyPassword(password, code) {
  let data = {
    password: password,
    code: code,
  };
  return request({
    method: 'post',
    url: Host1 + 'wallet/saveWalletPass',
    params: data,
  });
}

//上传初级实名认证图片
export function upLoadImg(data, fun) {
  upLoadFile('user/pcIdentityUploadFile', data, fun);
}

//上传高级认证的图片
export function upLoadHighImg(data, fun) {
  upLoadFile('user/pcUploadHighAuthFile', data, fun);
}

//上传图片
function upLoadFile(url, data, fun) {
  axios({
    method: 'post',
    url: Host + url,
    headers: {
      'Content-type': 'multipart/form-data',
      'X-Requested-Token': localStorage.getItem('token') || '',
      'X-Requested-YyyfToken': localStorage.getItem('yyyfToken') || '',
      locale: languageCode2BELocalCode(getCurrentLanguage()),
    },
    data: data,
  })
    .then(res => {
      if (res.data.code === 200) {
        fun(res.data.data);
      } else if (res.data.code === 500) {
        this.$message.warning(this.$t('personal.prove.fail'));
      } else {
        this.$message.warning(res.data.msg);
      }
    })
    .catch(() => {
      this.$message.warning(this.$t('personal.prove.fail'));
    });
}

//提交高级认证
export function saveHighAuth(data) {
  return request({
    method: 'post',
    url: Host + 'user/saveHighAuth',
    params: data,
  });
}

// 初级认证驳回理由
export function selectLowRemark({userId}) {
  return request({
    method: 'post',
    url: Host + 'user/selectLowRemark',
    params: {userId},
  });
}

// 高级认证驳回理由
export function selectHighRemark({userId}) {
  return request({
    method: 'post',
    url: Host + 'user/selectHighRemark',
    params: {userId},
  });
}
