/**
 * splitData 存储时分T线图的变量
 * @param value
 * @returns {array}
 */
function splitTData(data) {
  var categoryData = [];
  var values = [];
  var volumes = [];
  var lastIndex = data.length - 1;
  for (var i = 0; i < data.length; i++) {
    categoryData.push(data[i].date);
    if (i != lastIndex) {
      values[i] = data[i + 1].open;
    } else {
      values[i] = data[i].close;
    }
    volumes.push(data[i].total);
  }
  return {
    categoryData: categoryData,
    values: values,
    volumes: volumes,
  };
}

/**
 * splitKData 存储K线图的变量
 * @param value
 * @returns {array}
 */
function splitKData(data) {
  var categoryData = [];
  var values = [];
  var volumes = [];
  var lastIndex = data.length - 1;
  for (var i = 0; i < data.length; i++) {
    categoryData.push(data[i].date);
    var amount = [];
    amount[0] = data[i].open;
    if (i != lastIndex) {
      amount[1] = data[i + 1].open;
    } else {
      amount[1] = data[i].close;
    }
    amount[2] = data[i].lowest;
    amount[3] = data[i].highest;
    amount[4] = data[i].total;
    values.push(amount);
    var volume = [];
    volume[0] = i;
    volume[1] = amount[4];
    volume[2] = amount[0] > amount[1] ? 1 : -1;
    volumes.push(volume);
  }
  return {
    categoryData: categoryData,
    values: values,
    volumes: volumes,
  };
}
/**
 * splitDeData 存储深度线图的变量
 * @param value
 * @returns {array}
 */
function splitDeData(buyData, saleData) {
  var length =
    buyData.length < saleData.length ? buyData.length : saleData.length;
  var depthData = [[], []];
  var buyTotal = 0;
  var saleTotal = 0;
  // for (var i = 0; i < length - 1; i++) {
  for (var i = length - 1; i >= 0; i--) {
    saleTotal += saleData[i].totalNum;
    buyTotal += buyData[i].totalNum;
    depthData[0].push([saleData[i].unitPrice, saleTotal]);
    depthData[1].push([buyData[i].unitPrice, buyTotal]);
  }

  return depthData;
}

/**
 * formatValue 全局浮点格式化函数
 * @param value
 * @returns string
 */
const formatValue = function formatValue(value) {
  if (!value || value == 0) return '0.000000';
  var val = parseFloat(value);
  if (val < 0) {
    val = -val;
  }
  if (val < 0.001) {
    value = (parseInt(value * 1e8) / 1e8).toFixed(8);
  } else if (val < 0.1) {
    value = (parseInt(value * 1e6) / 1e6).toFixed(6);
  } else if (val < 10) {
    value = (parseInt(value * 1e4) / 1e4).toFixed(4);
  } else {
    value = (parseInt(value * 1e2) / 1e2).toFixed(2);
  }
  return value;
};
function calculateMA(dayCount, data) {
  var result = [];
  for (var i = 0, len = data.values.length; i < len; i++) {
    if (i < dayCount) {
      result.push('-');
      continue;
    }
    var sum = 0;
    for (var j = 0; j < dayCount; j++) {
      sum += data.values[i - j][1];
    }
    result.push(+(sum / dayCount).toFixed(3));
  }
  return result;
}

export default {
  splitTData,
  formatValue,
  splitKData,
  calculateMA,
  splitDeData,
};
