/*
函数，加法函数，用来得到精确的加法结果
说明：javascript的加法结果会有误差，在两个浮点数相加的时候会比较明显。这个函数返回较为精确的加法结果。
参数：arg1：第一个加数；arg2第二个加数；d要保留的小数位数（可以不传此参数，如果不传则不处理小数位数）
调用：Calc.Add(arg1,arg2,d)
返回值：两数相加的结果
*/

const Add = function formatValue(arg1, arg2, d) {
  (arg1 = arg1.toString()), (arg2 = arg2.toString());
  var arg1Arr = arg1.split('.'),
    arg2Arr = arg2.split('.'),
    d1 = arg1Arr.length == 2 ? arg1Arr[1] : '',
    d2 = arg2Arr.length == 2 ? arg2Arr[1] : '';
  var maxLen = Math.max(d1.length, d2.length);
  var m = Math.pow(10, maxLen);
  var result = Number(((arg1 * m + arg2 * m) / m).toFixed(maxLen));
  var d = arguments[2];
  return typeof d === 'number' ? Number(result.toFixed(d)) : result;
};
/*
函数：减法函数，用来得到精确的减法结果
说明：函数返回较为精确的减法结果。
参数：arg1：第一个加数；arg2第二个加数；d要保留的小数位数（可以不传此参数，如果不传则不处理小数位数
调用：Calc.Sub(arg1,arg2)
返回值：两数相减的结果
*/
const Sub = function formatValue(arg1, arg2, d) {
  return this.Add(arg1, -Number(arg2), arguments[2]);
};
/*
函数：乘法函数，用来得到精确的乘法结果
说明：函数返回较为精确的乘法结果。
参数：arg1：第一个乘数；arg2第二个乘数；d要保留的小数位数（可以不传此参数，如果不传则不处理小数位数)
调用：Calc.Mul(arg1,arg2)
返回值：两数相乘的结果
*/
const Mul = function formatValue(arg1, arg2, d) {
  var r1 = arg1.toString(),
    r2 = arg2.toString(),
    m,
    resultVal,
    d = arguments[2];
  m =
    (r1.split('.')[1] ? r1.split('.')[1].length : 0) +
    (r2.split('.')[1] ? r2.split('.')[1].length : 0);
  resultVal =
    (Number(r1.replace('.', '')) * Number(r2.replace('.', ''))) /
    Math.pow(10, m);
  return typeof d !== 'number'
    ? Number(resultVal)
    : Number(resultVal.toFixed(parseInt(d)));
};
/*
函数：除法函数，用来得到精确的除法结果
说明：函数返回较为精确的除法结果。
参数：arg1：除数；arg2被除数；d要保留的小数位数（可以不传此参数，如果不传则不处理小数位数)
调用：Calc.Div(arg1,arg2)
返回值：arg1除于arg2的结果
*/
const Div = function formatValue(arg1, arg2, d) {
  var r1 = arg1.toString(),
    r2 = arg2.toString(),
    m,
    resultVal,
    d = arguments[2];
  m =
    (r2.split('.')[1] ? r2.split('.')[1].length : 0) -
    (r1.split('.')[1] ? r1.split('.')[1].length : 0);
  resultVal =
    (Number(r1.replace('.', '')) / Number(r2.replace('.', ''))) *
    Math.pow(10, m);
  return typeof d !== 'number'
    ? Number(resultVal)
    : Number(resultVal.toFixed(parseInt(d)));
};
// const formatV = function formatValue(value) {
//   if (!value || value == 0) return '0.000000';
//   var val = parseFloat(value);
//   if (val < 0) {
//     val = -val;
//   }
//   if (val < 0.0001) {
//     value = Mul(value, 1e8, 8);
//     value = Div(value, 1e8, 8);
//     value = value.toFixed(8);
//   } else if (val < 0.1) {
//     value = Mul(value, 1e6, 6);
//     value = Div(value, 1e6, 6);
//     value = value.toFixed(6);
//   } else if (val < 10) {
//     value = Mul(value, 1e4, 4);
//     value = Div(value, 1e4, 4);
//     value = value.toFixed(4);
//   } else {
//     value = Mul(value, 1e2, 2);
//     value = Div(value, 1e2, 2);
//     value = value.toFixed(2);
//   }
//   return value;
// };
// const formatV = function formatValue(value) {
//   var decimal = 8;
//   if (isNaN(value)) {
//     return Number(0);
//   }
//   value = value.toString();
//   //小数点索引
//   var valueIndex = value.indexOf('.');
//   //存在小数的情况
//   if (valueIndex != -1) {
//     //小数位数据
//     var valueFloat = value.substring(valueIndex, value.length - 1);
//     //小数位长度大于格式化长度
//     if (valueFloat.length > decimal) {
//       //需要保留的小数位 + 1
//       var floatNum = parseFloat(value).toFixed(Number(decimal) + 1);
//       //截取数据，保留小数并不用四舍五入
//       value = floatNum.substring(0, floatNum.length - 1);
//     }
//   }
//   return value;
// };
/***
 * 格式化数据值 - 通过字符串截取方式
 * @param value 值
 * @param decimal 小数最大长度
 */
const formatV = function formatValueStr(value, decimal) {
  //默认长度为8
  if (decimal == null || decimal == '') {
    decimal = 8;
  }
  //防止NaN
  if (isNaN(value)) {
    return Number(0);
  }

  value = value.toString();
  //小数点索引
  var valueIndex = value.indexOf('.');
  //存在小数的情况
  if (valueIndex != -1) {
    //小数位数据
    var valueFloat = value.substring(valueIndex + 1);

    //判断格式化数据大小，保留小数
    value = parseFloat(value);
    if (value < 0.0001) {
      decimal = 8;
    } else if (value < 0.1) {
      decimal = 6;
    } else if (value < 10) {
      decimal = 4;
    } else {
      decimal = 2;
    }
    //小数位长度大于格式化长度
    if (valueFloat.length > decimal) {
      //需要保留的小数位 + 1
      var floatNum = parseFloat(value).toFixed(Number(decimal) + 1);
      //截取数据，保留小数并不用四舍五入
      value = floatNum.substring(0, floatNum.length - 1);
    }
  }
  return parseFloat(value);
};
export function formatX(value) {
  var decimal = 8;
  if (isNaN(value)) {
    return Number(0);
  }
  value = value.toString();
  //小数点索引
  var valueIndex = value.indexOf('.');
  //存在小数的情况
  if (valueIndex != -1) {
    //小数位数据
    var valueFloat = value.substring(valueIndex, value.length - 1);
    //小数位长度大于格式化长度
    if (valueFloat.length > decimal) {
      //需要保留的小数位 + 1
      var floatNum = parseFloat(value).toFixed(Number(decimal) + 1);
      //截取数据，保留小数并不用四舍五入
      value = floatNum.substring(0, floatNum.length - 1);
    }
  }
  return parseFloat(value);
}

/**
 * formatW 百分比小数格式化处理
 * @param value
 * @returns {string}
 */
const formatW = function formatWalue(value) {
  if (!value || value == 0) return '0.00';
  return (value = (parseInt(value * 1e2) / 1e2).toFixed(2));
};

/**
 * splitValue BTC-USDT变BTC/USDT
 * @param value
 * @returns {array}
 */
const splitV = function splitValue(value) {
  var lets = value.split('-');
  var arr = lets[0] + '/' + lets[1];

  return arr;
};

/**
 * splitValue BTC-USDT变BTC
 * @param value
 * @returns {array}
 */
const splitW = function splitWalue(value) {
  var lets = value.split('-');
  var arr = lets[0];

  return arr;
};

/**
 * splitValue 获取当前时间
 * @param value
 * @returns {array}
 */
export function formatDate(date, fmt) {
  if (/(y+)/.test(fmt)) {
    fmt = fmt.replace(
      RegExp.$1,
      (date.getFullYear() + '').substr(4 - RegExp.$1.length)
    );
  }
  let o = {
    'M+': date.getMonth() + 1,
    'd+': date.getDate(),
    'h+': date.getHours(),
    'm+': date.getMinutes(),
    's+': date.getSeconds(),
  };
  for (let k in o) {
    if (new RegExp(`(${k})`).test(fmt)) {
      let str = o[k] + '';
      fmt = fmt.replace(
        RegExp.$1,
        RegExp.$1.length === 1 ? str : ('00' + str).substr(str.length)
      );
    }
  }
  return fmt;
}

export default {
  Add,
  Sub,
  Mul,
  Div,
  formatV,
  splitV,
  splitW,
  formatW,
  formatDate,
  formatX,
};
